This is unreleased documentation for the main (development) branch of crypto-glue.

BoxedMontyParams

Struct BoxedMontyParams 

pub struct BoxedMontyParams(/* private fields */);
Parameters to efficiently go to/from the Montgomery form for an odd modulus whose size and value are both chosen at runtime.

Implementations

Source

impl BoxedMontyParams

pub fn new(modulus: Odd<BoxedUint>) -> Self

Instantiates a new set of BoxedMontyParams representing the given modulus.

TODO(tarcieri): DRY out with MontyParams::new?

pub fn new_vartime(modulus: Odd<BoxedUint>) -> Self

Instantiates a new set of BoxedMontyParams representing the given modulus. This version operates in variable-time with respect to the modulus.

TODO(tarcieri): DRY out with MontyParams::new_vartime?

pub fn modulus(&self) -> &Odd<BoxedUint>

Modulus value.

pub fn bits_precision(&self) -> u32

Bits of precision in the modulus.